#include <iostream>                // std::cout
#include <functional>              // std::bind
#include <fstream>
#include <chrono>
#include <random>
#include <iterator>
#include <cstring>
using namespace std;
#include <unistd.h>
#include <sys/stat.h>

bool debug = false; // debug messages ON

int test_dir( char* path )
{
    struct stat st;
    if ( stat( path, &st ) == 0 )
    {
	if ( S_ISDIR( st.st_mode ) ) 
	    return 0;
    }
    if (debug) cout << "create new directory: " << path << endl;
    int ret;
    for (char* p = strchr(path + 1, '/'); ; p = strchr(p + 1, '/')) {
        if (p) *p = '\0';
        if ((ret = mkdir(path, 0755)) == -1)
            if (errno != EEXIST) 
		break;
        if (p) *p = '/';
        else break;
    }
    return ret;
}

void help( const char *prg )
{
    cout << "usage: [-l <max_length>][-d <dirctory>][-v] " << prg << " <file_names_list>" << endl;
}

int main( int argc, char *argv[] ) 
{
    size_t limit = 100000;             // max files length
    string dir( "." );
    const char *switches = "d:l:vh";   // exec options
    char c;
    while ( ( c = getopt( argc, argv, switches  ) ) != -1 ) {
        switch( c ) {
            case 'd' :
                dir = string( optarg );
		if ( test_dir( (char*)dir.c_str() ) != 0 )
		{
                    cerr << "create directory error: " << dir << endl;
		    exit( EXIT_FAILURE );
		}
                break;
            case 'l' : if ( atol( optarg ) > 0 ) limit = atol( optarg ); break;
            case 'v' : debug = true; break;
            default  : 
                help( argv[ 0 ] ); 
                exit( 'h' == c ? EXIT_SUCCESS : EXIT_FAILURE );
       }
    }
    random_device rd;                  // produces non-deterministic random numbers, if supported
    const size_t divider = rd.max() / limit;
    if( argc != optind + 1 )
    {
        help( argv[ 0 ] );
        exit( EXIT_FAILURE );
    }
    ifstream fin;
    fin.open( argv[ optind ] );
    if ( !fin )
    {
        cerr << "such file not found: " << argv[ optind ] << endl;
        return EXIT_FAILURE;
    }
    while ( fin )
    {
	string line;
	getline( fin, line );
	if( line.empty() ) continue;
        string path = dir + "/" + line;
        ofstream fou( dir + "/" + line );
        if( !fou )
        {
            cerr << "create file error: " << path << endl;
            continue;
	}
	ostream_iterator<char> oi( fou, "" );
	size_t length = rd() / divider;
        if (debug)
            cout << path << " : " << length << endl;
	for (size_t i = 0; i < length; i++)
	    *oi++ = '0';
	fou.close();
    } 
    return EXIT_SUCCESS;
}
